@@ -26,12 +26,15 @@ netsnmp_feature_require(interface_ioctl_flags_set);
 #ifdef HAVE_PCI_LOOKUP_NAME
 #include <pci/pci.h>
 #include <setjmp.h>
+#ifndef PCI_NONRET
+#define PCI_NONRET
+#endif
 static struct pci_access *pci_access;
 
 /* Avoid letting libpci call exit(1) when no PCI bus is available. */
 static int do_longjmp =0;
 static jmp_buf err_buf;
-static void
+PCI_NONRET static void
 netsnmp_pci_error(char *msg, ...)
 {
     va_list args;
@@ -69,7 +72,7 @@ typedef __u8 u8;           /* ditto */
 
 #include <net-snmp/agent/net-snmp-agent-includes.h>
 
-#if HAVE_SYS_IOCTL_H
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
 #else
 #error "linux should have sys/ioctl header"
@@ -140,7 +143,7 @@ static void init_libpci(void)
      * When snmpd is run inside an OpenVZ container or on a Raspberry Pi system
      * /proc/bus/pci is not available.
      */
-    if (stat("/proc/bus/pci", &stbuf) == 0)
+    if (stat("/proc/bus/pci", &stbuf) < 0)
         return;
 
     pci_access = pci_alloc();
@@ -768,10 +771,12 @@ netsnmp_arch_interface_container_load(netsnmp_container* container,
         char           *stats, *ifstart = line;
         u_int           flags;
         oid             if_index;
+        size_t          len;
 
         flags = 0;
-        if (line[strlen(line) - 1] == '\n')
-            line[strlen(line) - 1] = '\0';
+        len = strlen(line);
+        if (len && line[len - 1] == '\n')
+            line[len - 1] = '\0';
 
         while (*ifstart && *ifstart == ' ')
             ifstart++;
