@@ -27,13 +27,13 @@ SOFTWARE.
 ******************************************************************/
 #include <net-snmp/net-snmp-config.h>
 
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
@@ -44,11 +44,11 @@ SOFTWARE.
 #endif
 #include <stdio.h>
 #include <ctype.h>
-#if TIME_WITH_SYS_TIME
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# if HAVE_SYS_TIME_H
+# ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # else
 #  include <time.h>
@@ -151,10 +151,10 @@ main(int argc, char *argv[])
                  * free the last (unused) variable 
                  */
                 if (vp->name)
-                    free((char *) vp->name);
+                    free(vp->name);
                 if (vp->val.string)
-                    free((char *) vp->val.string);
-                free((char *) vp);
+                    free(vp->val.string);
+                free(vp);
 
                 if (command == SNMP_MSG_GETBULK) {
                     if (nonRepeaters == -1) {
@@ -185,6 +185,8 @@ main(int argc, char *argv[])
                 }
             }
         }
+	if (copy)
+	    snmp_free_pdu(copy);
         copy = snmp_clone_pdu(pdu);
         if (command == SNMP_MSG_TRAP2) {
             /*
@@ -282,6 +284,7 @@ main(int argc, char *argv[])
     /* NOTREACHED */
 
 out:
+    netsnmp_cleanup_session(&session);
     SOCK_CLEANUP;
     return exit_code;
 }
@@ -306,7 +309,7 @@ input_variable(netsnmp_variable_list * vp)
         vp->name_length = 0;
         return 0;
     }
-    if (buf[val_len - 1] == '\n')
+    if (val_len && buf[val_len - 1] == '\n')
         buf[--val_len] = 0;
     if (*buf == '$') {
         switch (toupper((unsigned char)(buf[1]))) {
